@@ -179,8 +179,9 @@ class SimulationRunner(object):
                             smoothing=0,
                             bar_format=bar_format)
                 with pbar as progress_bar:
-                    for _, total in line_iterator:
-                        progress_bar.update(1)
+                    for current, total in line_iterator:
+                        progress_bar.n = current
+                        progress_bar.update(0)
                     progress_bar.n = progress_bar.total
             except (StopIteration):
                 if pbar is not None:
@@ -271,7 +272,7 @@ class SimulationRunner(object):
                         params[k] = float(v)
                     except ValueError:
                         # Keep it as a string
-                        if str(v) == "" or any(not c.isalnum() for c in v):
+                        if str(v) == "":
                             params[k] = None
                         else:
                             params[k] = str(v)
